#
# spec file for package tree-sitter-bash
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         _name bash
Name:           tree-sitter-bash
Version:        0.23.3
Release:        1.1
Summary:        Bash grammar for tree-sitter
License:        MIT
URL:            https://github.com/tree-sitter/tree-sitter-bash
Source0:        %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  tree-sitter
%treesitter_grammars %{_name}

%description
%{summary}.

%prep
%autosetup

%build
%treesitter_configure
%treesitter_build

%install
%treesitter_install
%treesitter_devel_install

#neovim stuff
install -d %{buildroot}%{_libdir}/tree_sitter
ln -s %{_libdir}/lib%{name}.so %{buildroot}%{_libdir}/tree_sitter/%{_name}.so

%files
%license LICENSE
%treesitter_files
%{_libdir}/tree_sitter/%{_name}.so
%if 0%{?suse_version} < 1600
%dir %{_libdir}/tree_sitter
%endif

%treesitter_devel_package

%changelog
* Wed Dec  4 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.23.3:
  * ci(publish): add attestations and generate parser
- update to 0.23.2:
  * build: update bindings
- update to 0.23.1:
  * fix: fix Python bindings
- update to 0.23.0:
  * build: update bindings
  * ci: update workflows
  * fix: don't copy to null heredoc delimiters
  * fix: don't copy null heredoc delimiters
- add symlink for neovim
- switch to download_files service, as we stay with the releases
  anyway, and nothing special needs to happen for preparing the
  sources
- add devel package
* Mon Mar 25 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Update to version 0.21.0:
  * docs: add pypi badge
  * feat!: use the array api in the scanner
  * build: update makefile for macos installation
  * ci: bump tree-sitter/parser-setup-action from 1.1 to 1.2
  * ci: update workflows
  * build: update bindings and versions
  * docs: update badges
  * ci: bump actions/setup-node from 3 to 4
  * ci: bump actions/checkout from 3 to 4
  * ci: add dependabot for actions
  * docs: remove unnecessary space
  * Remove AppVeyor (#247)
  * fix: use `iswalpha`
* Mon Feb 26 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Initial packaging for openSUSE
- Update to version 0.20.5:
  * chore: update parse script
  * chore: update tests
  * chore: generate
  * fix: allow asterisk in globs
  * fix: partial revert redirect changes, allow command sub in numbers w/ a base
  * fix: mark end when parsing strings
  * fix: better glob parsing
  * fix: parse single quote strings for certain regex tokens
  * fix: account for escaped opening braces in regex parsing
